#[non_exhaustive]pub enum ControlRemoteAccess {
Enabled,
EnabledManagedDomain,
EnabledManagedDomainTimeLimited,
NotAllowed,
Reserved(u8),
}Expand description
Control remote access over internet — ETSI EN 300 468 Table 58.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enabled
0b00 — redistribution over the Internet is enabled.
EnabledManagedDomain
0b01 — redistribution over the Internet is enabled but only within a managed domain.
EnabledManagedDomainTimeLimited
0b10 — redistribution over the Internet is enabled but only within a managed domain and after a certain short period of time.
NotAllowed
0b11 — redistribution over the Internet is not allowed.
Reserved(u8)
Reserved/unallocated wire value, preserved verbatim for round-trip.
Implementations