#[non_exhaustive]pub enum HandOverType {
DvbIdenticalNeighbouringCountry,
DvbLocalVariation,
DvbAssociatedService,
Reserved(u8),
}Expand description
Hand-over type — ETSI EN 300 468 Table 62.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DvbIdenticalNeighbouringCountry
0x1 — DVB hand-over to an identical service in a neighbouring country.
DvbLocalVariation
0x2 — DVB hand-over to a local variation of the same service.
DvbAssociatedService
0x3 — DVB hand-over to an associated service.
Reserved(u8)
Reserved/unallocated wire value, preserved verbatim for round-trip.
Implementations
Sourceimpl HandOverType
impl HandOverType