STD Descriptor — ISO/IEC 13818-1 2.6.32 (tag 0x11).
Indicates whether the leak method of buffer management is valid.
Structs
- StdDescriptor
- STD Descriptor.
Constants
- TAG
- Descriptor tag for STD_descriptor.
STD Descriptor — ISO/IEC 13818-1 2.6.32 (tag 0x11).
Indicates whether the leak method of buffer management is valid.