pub struct RealTimeParameters {
pub delta_t: u16,
pub table_boundary: bool,
pub frame_boundary: bool,
pub address: u32,
}Expand description
Time-slicing / MPE-FEC real-time parameters (EN 301 192 9.10, Table 46).
32 bits: delta_t(12) | table_boundary(1) | frame_boundary(1)
| address(18).
Fields
delta_t: u1612-bit delta_t — time until the start of the next burst (in units of
the MPE-FEC frame, see 9.10).
table_boundary: booltable_boundary flag.
frame_boundary: boolframe_boundary flag.
address: u3218-bit address — byte position of the first payload byte of this
section within the MPE-FEC frame table.