#[non_exhaustive]pub enum NitKind {
Actual,
Other,
}Expand description
NIT kind — distinguishes 0x40 (actual) from 0x41 (other).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Actual
NIT for the transport stream the receiver is tuned to.
Other
NIT describing other transport streams in the same network.