pub enum NitKind {
Actual,
Other,
}Expand description
NIT kind — distinguishes 0x40 (actual) from 0x41 (other).
Variants
Actual
NIT for the transport stream the receiver is tuned to.
Other
NIT describing other transport streams in the same network.